@@ -17,7 +17,8 @@ from octadocs.navigation.types import (
     NavigationItem,
     SortKey,
 )
-from octadocs.query import SelectResult, query
+from octadocs.query import query
+from octadocs.types import SelectResult
 from singledispatchmethod import singledispatchmethod
 
 if sys.version_info >= (3, 8):
@@ -45,7 +46,7 @@ def sort_key(navigation_item: NavigationItem) -> SortKey:
 
     return SortKey(
         is_index=not is_index_md(navigation_item),
-        position=navigation_item.position,
+        position=str(navigation_item.position),
         title=title,
     )
 
