@@ -1,5 +1,7 @@
+from copy import deepcopy
+
 from deepmerge import always_merger
-from octadocs.octiron.types import Context
+from octadocs.types import Context
 
 
 def merge(first: Context, second: Context) -> Context:
@@ -8,7 +10,7 @@ def merge(first: Context, second: Context) -> Context:
 
     Second context can override the first.
     """
-    return always_merger.merge(
+    return deepcopy(always_merger.merge(
         base=first,
         nxt=second,
-    )
+    ))
