@@ -1,8 +1,8 @@
 from pathlib import Path
-from typing import Iterator, Optional
+from typing import Iterator, Optional, Any, Dict
 
 import rdflib
-from octadocs.octiron.types import Context, Triple
+from octadocs.types import Context, Triple
 
 
 class Loader:
@@ -24,18 +24,23 @@ class Loader:
     # JSON-LD context
     context: Context
 
+    # Named contexts from Octiron config
+    named_contexts: Optional[Dict[str, Any]] = None
+
     def __init__(
         self,
         path: Path,
         local_iri: rdflib.URIRef,
         global_url: Optional[str],
         context: Context,
+        named_contexts: Optional[Dict[str, Any]] = None,
     ) -> None:
         """Initialize the data loader."""
         self.path = path
         self.context = context
         self.local_iri = local_iri
         self.global_url = global_url
+        self.named_contexts = named_contexts
 
     def stream(self) -> Iterator[Triple]:
         """Read the source data and return a stream of triples."""
