@@ -2,8 +2,8 @@ from typing import Iterator
 
 import yaml
 from octadocs.octiron.plugins import Loader
-from octadocs.octiron.types import OCTA, Triple
 from octadocs.octiron.yaml_extensions import SafeLoader, as_triple_stream
+from octadocs.types import OCTA, Triple
 from rdflib import RDF
 
 
@@ -20,10 +20,14 @@ class YAMLLoader(Loader):
         with open(self.path, 'r') as yaml_file:
             raw_data = yaml.load(yaml_file, Loader=SafeLoader)
 
+        if raw_data is None:
+            return
+
         yield from as_triple_stream(
             raw_data=raw_data,
             context=self.context,
             local_iri=self.local_iri,
+            named_contexts=self.named_contexts,
         )
 
         # The IRI of the local page is a page.
